import { SocketDtoDirectionEnum, SocketDtoTypeEnum } from '@smallstack/axios-api-client';
import { WIDGET_FILTER_INPUT_NUMBER, WIDGET_FILTER_INPUT_SELECT } from '@smallstack/core-common';

var CONFIGURATION_KEYS$1;
(function (CONFIGURATION_KEYS) {
    CONFIGURATION_KEYS["GLOBAL_VARIABLE_NAME"] = "globalVariableName";
    CONFIGURATION_KEYS["ARRAY_SCHEMA"] = "arraySchema";
})(CONFIGURATION_KEYS$1 || (CONFIGURATION_KEYS$1 = {}));
var SOCKETS$1;
(function (SOCKETS) {
    SOCKETS["VALUE"] = "value";
})(SOCKETS$1 || (SOCKETS$1 = {}));
const AddToArrayFormWidget = {
    name: "AddToArrayForm",
    configuration: {
        templateName: "Add to Array Form",
        templateDescription: "Ein Widget, welches ein Formular anzeigt, um ein Element zu einem Array hinzuzufügen, welches sich in einem Objekt auf dem aktuellen Kontext befindet.",
        icon: "add",
        dataSchema: {
            type: "object",
            properties: {
                [CONFIGURATION_KEYS$1.GLOBAL_VARIABLE_NAME]: {
                    type: "string",
                    title: "Globale Variable Name",
                    description: "Der Name der Variable, welche das Array enthält, welches erweitert werden soll."
                },
                [CONFIGURATION_KEYS$1.ARRAY_SCHEMA]: {
                    type: "string",
                    title: "Formular Schema",
                    description: "Das Schema des Formulars, welches das neue Element beschreibt.",
                    "x-schema-form": {
                        widget: "monaco",
                        monacoLanguage: "json"
                    }
                }
            }
        },
        sockets: [{ direction: SocketDtoDirectionEnum.Out, name: SOCKETS$1.VALUE, type: SocketDtoTypeEnum.Object }]
    },
    component: () => import('./smallstack-form-widgets-add-to-array-form-widget.component-4198f3a7.mjs').then((m) => m.AddToArrayFormWidgetComponent)
};

const FilterFieldWidget = {
    name: "FilterField",
    component: () => import('./smallstack-form-widgets-filter-field-widget.component-f55e82db.mjs').then((m) => m.FilterFieldWidgetComponent),
    configuration: {
        templateName: "Filter",
        templateDescription: "Zeigt ein passendes Feld an, welches zum Filtern verwendet werden kann.",
        icon: "filter"
    }
};

const I18nFilterWidget = {
    name: "I18nFilter",
    component: () => import('./smallstack-form-widgets-i18n-filter-widget.component-b2c4b5e7.mjs').then((m) => m.I18nFilterWidgetComponent),
    configuration: {
        templateName: "Übersetzungen Filter",
        templateDescription: "Zeigt ein Feld an, welches zum Filtern von Übersetzungen verwendet werden kann.",
        icon: "filter"
    }
};

const NumberFilterWidget = {
    name: WIDGET_FILTER_INPUT_NUMBER,
    component: () => import('./smallstack-form-widgets-number-filter-widget.component-1a35d332.mjs').then((m) => m.NumberFilterWidgetComponent),
    configuration: {
        templateName: "Nummern Filter",
        templateDescription: "Filtert nach einer Zahl",
        icon: "filter"
    }
};

var CONFIGURATION_KEYS;
(function (CONFIGURATION_KEYS) {
    CONFIGURATION_KEYS["GLOBAL_VARIABLE_NAME"] = "globalVariableName";
    CONFIGURATION_KEYS["TYPE_PATH"] = "typePath";
    CONFIGURATION_KEYS["BTN_TEXT"] = "btnText";
})(CONFIGURATION_KEYS || (CONFIGURATION_KEYS = {}));
var SOCKETS;
(function (SOCKETS) {
    SOCKETS["SAVED_SUCCESSFULLY"] = "savedSuccessfully";
})(SOCKETS || (SOCKETS = {}));
const SaveModelBtnWidget = {
    name: "SaveModelBtn",
    configuration: {
        templateName: "Entität Speichern Button",
        templateDescription: "Ein Widget, welches einen Button anzeigt, um eine Entität zu speichern.",
        icon: "save--v1",
        dataSchema: {
            type: "object",
            properties: {
                [CONFIGURATION_KEYS.TYPE_PATH]: {
                    type: "string",
                    title: "Datentyp",
                    "x-schema-form": {
                        widget: "types"
                    }
                },
                [CONFIGURATION_KEYS.GLOBAL_VARIABLE_NAME]: {
                    type: "string",
                    title: "Variable Name",
                    description: "Der Name der Variable, welche das Array enthält, welches erweitert werden soll."
                },
                [CONFIGURATION_KEYS.BTN_TEXT]: {
                    type: "string",
                    title: "Button Text",
                    description: "Der Text, welcher auf dem Button angezeigt werden soll.",
                    default: "Speichern"
                }
            }
        },
        sockets: [
            { direction: SocketDtoDirectionEnum.Out, name: SOCKETS.SAVED_SUCCESSFULLY, type: SocketDtoTypeEnum.Boolean }
        ]
    },
    component: () => import('./smallstack-form-widgets-save-model-btn-widget.component-38990739.mjs').then((m) => m.SaveModelBtnWidgetComponent)
};

const SelectFilterWidget = {
    name: WIDGET_FILTER_INPUT_SELECT,
    component: () => import('./smallstack-form-widgets-select-filter-widget.component-f2a910b2.mjs').then((m) => m.SelectFilterWidgetComponent),
    configuration: {
        templateName: "Auswahl Filter",
        templateDescription: "Filtert nach Auswahl verschiedener Werte",
        icon: "filter"
    }
};

const StringFilterWidget = {
    name: "StringFilter",
    component: () => import('./smallstack-form-widgets-string-filter-widget.component-6f21db9e.mjs').then((m) => m.StringFilterWidgetComponent),
    configuration: {
        templateName: "String Filter",
        templateDescription: "Zeigt ein Feld an, welches zum Filtern von Zeichenketten verwendet werden kann.",
        icon: "filter"
    }
};

const DateFilterWidget = {
    name: "DateFilter",
    component: () => import('./smallstack-form-widgets-date-filter-widget.component-0ec51324.mjs').then((m) => m.DateFilterWidgetComponent),
    configuration: {
        templateName: "Datum Filter",
        templateDescription: "Zeigt Felder an, welche zum Filtern von einem Datum verwendet werden können.",
        icon: "filter"
    }
};

function addFormWidgets(widgetRegistry) {
    widgetRegistry.addWidget(AddToArrayFormWidget);
    widgetRegistry.addWidget(SaveModelBtnWidget);
    widgetRegistry.addWidget(FilterFieldWidget);
    widgetRegistry.addWidget(StringFilterWidget);
    widgetRegistry.addWidget(NumberFilterWidget);
    widgetRegistry.addWidget(SelectFilterWidget);
    widgetRegistry.addWidget(I18nFilterWidget);
    widgetRegistry.addWidget(DateFilterWidget);
}

/**
 * Generated bundle index. Do not edit.
 */

export { CONFIGURATION_KEYS$1 as C, SOCKETS$1 as S, CONFIGURATION_KEYS as a, SOCKETS as b, addFormWidgets as c };
//# sourceMappingURL=smallstack-form-widgets-smallstack-form-widgets-71b76008.mjs.map
